@@ -176,7 +176,7 @@ SDL3_SYM(bool,DetachVirtualJoystick,(SDL_JoystickID a),(a),return)
 SDL3_SYM(bool,DisableScreenSaver,(void),(),return)
 SDL3_SYM(SDL_Surface*,DuplicateSurface,(SDL_Surface *a),(a),return)
 SDL3_SYM(bool,EnableScreenSaver,(void),(),return)
-SDL3_SYM_RENAMED_BOOL(bool,EncloseFPoints,GetRectEnclosingPointsFloat,(const SDL_FPoint *a, int b, const SDL_FRect *c, SDL_FRect *d),(a,b,c,d),return)
+SDL3_SYM(bool,GetRectEnclosingPointsFloat,(const SDL_FPoint *a, int b, const SDL_FRect *c, SDL_FRect *d),(a,b,c,d),return)
 SDL3_SYM_RENAMED_BOOL(bool,EnclosePoints,GetRectEnclosingPoints,(const SDL_Point *a, int b, const SDL_Rect *c, SDL_Rect *d),(a,b,c,d),return)
 SDL3_SYM(bool,EventEnabled,(Uint32 a),(a),return)
 SDL3_SYM(bool,FillSurfaceRect,(SDL_Surface *a, const SDL_Rect *b, Uint32 c),(a,b,c),return)
@@ -395,7 +395,8 @@ SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetTextureAlphaMod,(SDL_Texture *a, Uint8 *b),
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetTextureBlendMode,(SDL_Texture *a, SDL_BlendMode *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetTextureColorMod,(SDL_Texture *a, Uint8 *b, Uint8 *c, Uint8 *d),(a,b,c,d),return)
 SDL3_SYM(SDL_PropertiesID,GetTextureProperties,(SDL_Texture *a),(a),return)
-SDL3_SYM_PASSTHROUGH_RETCODE(bool,GetTextureScaleMode,(SDL_Texture *a, SDL_ScaleMode *b),(a,b),return)
+SDL3_SYM(bool,GetTextureScaleMode,(SDL_Texture *a, SDL_ScaleMode *b),(a,b),return)
+SDL3_SYM(bool,GetTextureSize,(SDL_Texture *a, float *b, float *c),(a,b),return)
 SDL3_SYM(Uint64,GetThreadID,(SDL_Thread *a),(a),return)
 SDL3_SYM_PASSTHROUGH(const char*,GetThreadName,(SDL_Thread *a),(a),return)
 SDL3_SYM(Uint64,GetTicks,(void),(),return)
@@ -455,7 +456,7 @@ SDL3_SYM_PASSTHROUGH_BOOL(bool,HasClipboardText,(void),(),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,HasEvent,(Uint32 a),(a),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,HasEvents,(Uint32 a, Uint32 b),(a,b),return)
 SDL3_SYM_RENAMED_BOOL(bool,HasIntersection,HasRectIntersection,(const SDL_Rect *a, const SDL_Rect *b),(a,b),return)
-SDL3_SYM_RENAMED_BOOL(bool,HasIntersectionF,HasRectIntersectionFloat,(const SDL_FRect *a, const SDL_FRect *b),(a,b),return)
+SDL3_SYM(bool,HasRectIntersectionFloat,(const SDL_FRect *a, const SDL_FRect *b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,HasLASX,(void),(),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,HasLSX,(void),(),return)
 SDL3_SYM_PASSTHROUGH_BOOL(bool,HasMMX,(void),(),return)
@@ -474,8 +475,8 @@ SDL3_SYM(SDL_IOStream*,IOFromConstMem,(const void *a, size_t b),(a,b),return)
 SDL3_SYM(SDL_IOStream*,IOFromFile,(const char *a, const char *b),(a,b),return)
 SDL3_SYM(SDL_IOStream*,IOFromMem,(void *a, size_t b),(a,b),return)
 SDL3_SYM(bool,InitSubSystem,(Uint32 a),(a),return)
-SDL3_SYM_RENAMED_BOOL(bool,IntersectFRect,GetRectIntersectionFloat,(const SDL_FRect *a, const SDL_FRect *b, SDL_FRect *c),(a,b,c),return)
-SDL3_SYM_RENAMED_BOOL(bool,IntersectFRectAndLine,GetRectAndLineIntersectionFloat,(const SDL_FRect *a, float *b, float *c, float *d, float *e),(a,b,c,d,e),return)
+SDL3_SYM(bool,GetRectIntersectionFloat,(const SDL_FRect *a, const SDL_FRect *b, SDL_FRect *c),(a,b,c),return)
+SDL3_SYM(bool,GetRectAndLineIntersectionFloat,(const SDL_FRect *a, float *b, float *c, float *d, float *e),(a,b,c,d,e),return)
 SDL3_SYM_RENAMED_BOOL(bool,IntersectRect,GetRectIntersection,(const SDL_Rect *a, const SDL_Rect *b, SDL_Rect *c),(a,b,c),return)
 SDL3_SYM_RENAMED_BOOL(bool,IntersectRectAndLine,GetRectAndLineIntersection,(const SDL_Rect *a, int *b, int *c, int *d, int *e),(a,b,c,d,e),return)
 SDL3_SYM(bool,IsGamepad,(SDL_JoystickID a),(a),return)
@@ -642,7 +643,7 @@ SDL3_SYM(bool,SetRenderClipRect,(SDL_Renderer *a, const SDL_Rect *b),(a,b),retur
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,SetRenderDrawBlendMode,(SDL_Renderer *a, SDL_BlendMode b),(a,b),return)
 SDL3_SYM_PASSTHROUGH_RETCODE(bool,SetRenderDrawColor,(SDL_Renderer *a, Uint8 b, Uint8 c, Uint8 d, Uint8 e),(a,b,c,d,e),return)
 SDL3_SYM(bool,SetRenderLogicalPresentation,(SDL_Renderer *a, int b, int c, SDL_RendererLogicalPresentation d),(a,b,c,d),return)
-SDL3_SYM_PASSTHROUGH_RETCODE(bool,SetRenderTarget,(SDL_Renderer *a, SDL_Texture *b),(a,b),return)
+SDL3_SYM(bool,SetRenderTarget,(SDL_Renderer *a, SDL_Texture *b),(a,b),return)
 SDL3_SYM(bool,SetRenderViewport,(SDL_Renderer *a, const SDL_Rect *b),(a,b),return)
 SDL3_SYM(bool,SetStringProperty,(SDL_PropertiesID a, const char *b, const char *c),(a,b,c),return)
 SDL3_SYM(bool,SetSurfaceAlphaMod,(SDL_Surface *a, Uint8 b),(a,b),return)
